/*
 *  main.h - temporary file for devel
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
#ifndef MAIN_H
#define MAIN_H

#include "../config.h"
#include "glib.h"


#include "osdep.h"
#include "convert.h"

#define PROGRAM_NAME	"LX"
#define CONFIG_FILE		"lx.cfg"
#define ERROR_FILE		"lx.err"
#define HTML_FILE		"lx.htm"
#define INFO_FILE		"lx.inf"
#define RESULTS_FILE	"lx.xml"
#define REFERENCES_FILE	"lx.res"
#define REPAIRS_EXT 	".rep"

#define BUFF_SIZE		1024
#define SIZE_CALL		20
#define SIZE_ANT		40
#define NUM_LOC2CALL	10
#define NUM_CALL2LOC	10

#define BAND_GHZ		5
#define BAND_GHZ_ZERO 	9
#define RSTLEN          10

struct QSO_INFO;

struct CALL_INFO {
	char call[SIZE_CALL + 1];
	char filepath[BUFF_SIZE + 1];
	char filename[BUFF_SIZE + 1];
	char filename_err[BUFF_SIZE + 1];
	uint32_t loc;					// nenulove znamena, ze locator je zname a 
								// 
	// call tejto znacky je na 100%
	uint32_t refs;
	uint32_t temp;
	struct QSO_INFO *first_qso;
	struct QSO_INFO *odx;
	uint8_t categ;				// 0 - check log
	// char export; //1=single; 2=multi; 3=check

	// BYTE band; //nie je treba
	uint32_t score;
	uint32_t score_lost;
	uint32_t score_claimed;
	uint32_t qsos;					// valid
	uint32_t qsos_all;

	float pwr;
	uint32_t asl;
	char ant[SIZE_ANT];

	struct CALL_INFO *first_call_same_loc;
	struct CALL_INFO *next_call_same_loc;

	struct CALL_INFO *first_call_same_call;
	struct CALL_INFO *next_call_same_call;

	// CALL_INFO *ok_call; //nemoze byt pretoze v inom logu moze byt ina
	// znacka spravna (neda sa to brat vseobecne)
	struct CALL_INFO *next;
};

struct QSO_INFO {
	uint32_t dt;					// date, time
	uint8_t s_mode;
	uint8_t dupe;					// reported dupe in log

	struct CALL_INFO *s_call;			// sent
	char s_rst1[RSTLEN];
	uint16_t s_nr;

	struct CALL_INFO *r_call;			// received
	char r_rst1[RSTLEN];
	uint16_t r_nr;

	struct CALL_INFO *ok_call;			// correct RX info
	char ok_rst1[RSTLEN];
	uint16_t ok_nr;

	uint8_t pass;					// repaired by pass, 100=NOT IN THE LOG,
	// 101=DUPE, 102=BAD CALL (NOT IMPL YET)
	uint8_t wwl_outside;	/* WWL square is outside of the country */
	uint32_t QRB;
	uint32_t claimed_QRB;

	struct QSO_INFO *ok_qso;
	struct QSO_INFO *next;
};

struct forced_wwls {
	char call[SIZE_CALL + 1];
	uint32_t wwl;
};

struct bad_calls_t {
	char bad[SIZE_CALL + 1];
	char correct[SIZE_CALL + 1];
};

extern FILE *err, *inf;
extern char eprintf_load;
extern char *eprintf_filename;
extern uint32_t all_entries;
extern char ctest_name[];
extern char cfg_epath[];
extern char space[];
extern uint8_t *buf_ptr, *buf_free;
extern uint32_t buf_size;
extern uint32_t mem_used;
extern uint32_t calls;
extern struct CALL_INFO *first_call[BAND_NUM], *last_call[BAND_NUM];
extern int verbose_mode;
extern int forcedwwl_num;
extern struct forced_wwls forced[];
extern int bad_calls_cnt;
extern struct bad_calls_t bad_calls[];
extern int no_slashes;

int eprintf(const char *format, ...);

extern int fatals;

/* dwdb.c */

static inline char *safe_strncpy(char *dst, const char *src, size_t dst_size) {
    strncpy(dst, src, dst_size);
    if (strlen(src) >= dst_size) dst[dst_size - 1] = 0;
    return dst;
}


static inline char *safe_strncpy0(char *dst, const char *src, size_t dst_size) {
    if (!src) {
        *dst='\0';
        return dst;
    }

    strncpy(dst, src, dst_size);
    if (strlen(src) >= dst_size) dst[dst_size - 1] = 0;
    return dst;
}


#endif /* MAIN_H */
